import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl ='https://gist.githubusercontent.com/pethavenu/3ce407736913cab055984078a42d68e1/raw/47b0f13988ec2d123a4e4aedca28bb387aaf7b67/carsdataset.csv'
const width = 950;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };

// Load the earthquake data from a CSV file
d3.csv("earthquake_data.csv", function(error, data) {
  if (error) throw error;
  
  // Extract columns of latitude and longitude
  var latitude = data.map(function(d) { return +d.Latitude; });
  var longitude = data.map(function(d) { return +d.Longitude; });
  
  // Define the size of the scatter plot
  var width = 600;
  var height = 400;
  
  // Create an SVG element to hold the scatter plot
  var svg = d3.select("body")
    .append("svg")
    .attr("width", width)
    .attr("height", height);
  
  // Create a scale for the x and y axes
  var xScale = d3.scaleLinear()
    .domain([d3.min(longitude), d3.max(longitude)])
    .range([0, width]);
  
  var yScale = d3.scaleLinear()
    .domain([d3.min(latitude), d3.max(latitude)])
    .range([height, 0]);
  
  // Add the scatter plot points
  svg.selectAll("circle")
    .data(data)
    .enter()
    .append("circle")
    .attr("cx", function(d) { return xScale(+d.Longitude); })
    .attr("cy", function(d) { return yScale(+d.Latitude); })
    .attr("r", 5)
    .attr("fill", "blue");
  
  // Add labels to the x and y axes
  svg.append("text")
    .attr("transform", "translate(" + (width / 2) + "," + (height + 30) + ")")
    .style("text-anchor", "middle")
    .text("Longitude");
  
  svg.append("text")
    .attr("transform", "rotate(-90)")
    .attr("y", 0 - 50)
    .attr("x", 0 - (height / 2))
    .attr("dy", "1em")
    .style("text-anchor", "middle")
    .text("Latitude");
});
